@@ -25,7 +25,7 @@ tbr_sum <- function(.tbl, x, tcolumn, unit = "years", n, na.rm = FALSE) {
   .tbl <- .tbl %>%
     arrange(!! rlang::enquo(tcolumn)) %>%
     mutate("sum" := purrr::map(row_number(),
-                            ~tbr_sum_window(x = !! rlang::enquo(x), #column that indicates success/failure
+                            ~tbr_sum_window(x = !! rlang::enquo(x), #column to sum
                                       tcolumn = !! rlang::enquo(tcolumn), #posix formatted time column
                                       unit = unit,
                                       n = n,
@@ -62,8 +62,8 @@ tbr_sum_window <- function(x, tcolumn, unit = "years", n, i, na.rm) {
 
   # create a time-based window by calculating the duration between current row
   # and the previous rows select the rows where 0 <= duration <= n
-  window <- x[lubridate::as.duration(tcolumn[i] - tcolumn)/lubridate::duration(num = 1, units = unit) <= n & lubridate::as.duration(tcolumn[i] - tcolumn)/lubridate::duration(num = 1, units = unit) >= 0]
-
+  window <- open_window(x, tcolumn, unit = unit, n, i)
+  
   # calculates the sum
   results <- sum(window, na.rm = na.rm)
 
